@@ -46,6 +46,7 @@ class Snake():
         self._canvHeight = canvHeight
         self._gridSize = self._gridSize
         self._actions = []
+        self._levelDataString = []
         self._appendCurrentState();
         
     def _appendCurrentState (self):
@@ -64,8 +65,8 @@ class Snake():
             x = self._canvWidth
         if y < 0:
             y = 0
-        elif y > self._canvHeigth:
-            y = self._canvHeigth
+        elif y > self._canvHeight:
+            y = self._canvHeight
     
         self._x = round(x, 2)
         self._y = round(y, 2)
@@ -82,7 +83,7 @@ class Snake():
         """Set the snake's movement speed"""
         self._speed = speed
         
-    def rotationSpeed(self, rotspeed):
+    def turnSpeed(self, rotspeed):
         """Set the snake's rotation speed"""
         self._rotspeed = rotspeed
         
